==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/normalmessagehandler.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>NormalMessageHandler</name>
    <message>
        <source>Single Messages</source>
        <translation>Einzelne Nachrichten</translation>
    </message>
    <message>
        <source>Message from %1</source>
        <translation>Nachricht von %1</translation>
    </message>
    <message>
        <source>Message received</source>
        <translation>Nachricht erhalten</translation>
    </message>
    <message>
        <source>Composing message</source>
        <translation>Nachricht schreiben</translation>
    </message>
    <message>
        <source>%1 - Message</source>
        <translation>%1 - Nachricht</translation>
    </message>
    <message>
        <source>Re: %1</source>
        <translation>Re: %1</translation>
    </message>
    <message>
        <source>Fw: %1</source>
        <translation>Fw: %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;The message with a error code %1 is received&lt;/b&gt;</source>
        <translation>&lt;b&gt;Die Nachricht mit dem Fehlercode %1 wurde erhalten&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Subject: %1</source>
        <translation>Thema: %1</translation>
    </message>
    <message>
        <source>&lt;no subject&gt;</source>
        <translation>&lt;kein Thema&gt;</translation>
    </message>
    <message>
        <source>Normal Messages</source>
        <translation>normale Nachrichten</translation>
    </message>
    <message>
        <source>Allows to exchange normal messages</source>
        <translation>Erlaubt das Austauschen normaler Nachrichten</translation>
    </message>
    <message>
        <source>Send message</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+Return</source>
        <comment>Send message</comment>
        <translation></translation>
    </message>
</context>
</TS>

==> vacuum-1.1.2_1798.tar.xz: vacuum-1.1.2_1798/src/translations/de/normalmessagehandler.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>NormalMessageHandler</name>
    <message>
        <source>Message from %1</source>
        <translation>Nachricht von %1</translation>
    </message>
    <message>
        <source>Message received</source>
        <translation>Nachricht erhalten</translation>
    </message>
    <message>
        <source>Composing message</source>
        <translation>Nachricht schreiben</translation>
    </message>
    <message>
        <source>%1 - Message</source>
        <translation>%1 - Nachricht</translation>
    </message>
    <message>
        <source>Re: %1</source>
        <translation>Re: %1</translation>
    </message>
    <message>
        <source>Fw: %1</source>
        <translation>Fw: %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;The message with a error code %1 is received&lt;/b&gt;</source>
        <translation>&lt;b&gt;Die Nachricht mit dem Fehlercode %1 wurde erhalten&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Subject: %1</source>
        <translation>Thema: %1</translation>
    </message>
    <message>
        <source>&lt;no subject&gt;</source>
        <translation>&lt;kein Thema&gt;</translation>
    </message>
    <message>
        <source>Normal Messages</source>
        <translation>normale Nachrichten</translation>
    </message>
    <message>
        <source>Allows to exchange normal messages</source>
        <translation>Erlaubt das Austauschen normaler Nachrichten</translation>
    </message>
    <message>
        <source>Send message</source>
        <translation>Sende Nachricht</translation>
    </message>
    <message>
        <source>Ctrl+Return</source>
        <comment>Send message</comment>
        <translation>Ctrl+Return</translation>
    </message>
    <message>
        <source>When receiving new single message</source>
        <translation>Wenn neue einzelne Nachricht empfangen</translation>
    </message>
</context>
</TS>
